<template>
  <el-dialog
    width="40%"
    title="工序节点编辑"
    top="15vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    :close-on-click-modal="false"
    class="edit-order-operation-dialog"
    id="edit-order-operation-dialog"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="operationDataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="工作中心" prop="workCenter">
            <el-select
              v-model="dataForm.workCenter"
              placeholder="工作中心"
              style="width: 100%"
              filterable
            >
              <el-option
                v-for="item in workCenterOptions"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="因素单位" prop="runTimeCodeDb">
            <el-select
              v-model="dataForm.runTimeCodeDb"
              placeholder="因素单位"
              style="width: 100%"
            >
              <el-option
                v-for="item in runTimeCodeDbOptions"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="机器运转因素" prop="machRunFactor">
            <el-input
              v-model="dataForm.machRunFactor"
              placeholder="机器运转因素"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="机器设置时间" prop="machSetupTime">
            <el-input
              v-model="dataForm.machSetupTime"
              placeholder="机器设置时间"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="劳力运转因素" prop="laborRunFactor">
            <el-input
              v-model="dataForm.laborRunFactor"
              placeholder="劳力运转因素"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="劳力设置时间" prop="laborSetupTime">
            <el-input
              v-model="dataForm.laborSetupTime"
              placeholder="劳力设置时间"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="人工类别" prop="laborClassNo">
            <el-select
              v-model="dataForm.laborClassNo"
              filterable
              placeholder="请选择人工类别"
              style="width:100%"
            >
              <el-option
                v-for="(item, index) in laborClassNoOptions"
                :label="item.label"
                :value="item.value"
                :key="index"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="班组人员" prop="crewSize">
            <el-input
              v-model="dataForm.crewSize"
              placeholder="班组人员"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="外部工序项目" prop="outsideOpItem">
            <el-select
              v-model="dataForm.outsideOpItem"
              placeholder="外部工序项目"
              style="width: 100%"
              clearable
            >
              <el-option
                v-for="item in outsideOpItemOptions"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12"> </el-col>
      </el-row>
    </el-form>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { moRouringOperation } from '@/api/plan/morouting'
import { validateSixDecimalPositives } from '@/util/validate'
import { remote } from '../../../api/admin/dict'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    currOrderOperation: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      workCenterOptions: [],
      runTimeCodeDbOptions: [],
      dataForm: {
        id: 0,
        workCenter: null,
        machRunFactor: 0,
        machSetupTime: 0,
        laborClassNo: null,
        laborRunFactor: 0,
        laborSetupTime: 0,
        runTimeCodeDb: null,
        crewSize: 1,
        outsideOpItem: null,
        moId: null
      },
      dataRule: {
        workCenter: [
          { required: true, message: '工作中心不能为空', trigger: 'change' }
        ],
        machRunFactor: [
          { required: true, message: '机器运转因素不能为空', trigger: 'blur' },
          { validator: validateSixDecimalPositives, trigger: 'blur' }
        ],
        machSetupTime: [
          { required: true, message: '机器设置时间不能为空', trigger: 'blur' },
          { validator: validateSixDecimalPositives, trigger: 'blur' }
        ],
        laborRunFactor: [
          { required: true, message: '劳力运转因素不能为空', trigger: 'blur' },
          { validator: validateSixDecimalPositives, trigger: 'blur' }
        ],
        laborSetupTime: [
          { required: true, message: '劳力设置时间不能为空', trigger: 'blur' },
          { validator: validateSixDecimalPositives, trigger: 'blur' }
        ],
        runTimeCodeDb: [
          { required: true, message: '因素单位不能为空', trigger: 'change' }
        ]
      },
      laborClassNoOptions: [],
      outsideOpItemOptions: []
    }
  },
  methods: {
    saveSelectRow() {
      this.$refs.operationDataForm.validate((valid) => {
        if (valid) {
          if (
            this.dataForm.machRunFactor == 0 &&
            this.dataForm.machSetupTime == 0 &&
            this.dataForm.laborRunFactor == 0 &&
            this.dataForm.laborSetupTime == 0
          ) {
            this.$message.error(
              '【机器运转因素】、【机器设置时间】、【劳力运转因素】、【劳力设置时间】中至少有一个字段的值须大于0'
            )
          } else {
            // 【人工类别】为空时【班组人员】必须为空，否则必须大于0
            let remindInfo = ''
            let remindFlag = false
            if (
              this.dataForm.laborClassNo == null ||
              this.dataForm.laborClassNo == ''
            ) {
              if (
                this.dataForm.crewSize != null &&
                this.dataForm.crewSize != ''
              ) {
                remindFlag = true
                remindInfo = '【人工类别】为空时【班组人员】必须为空'
              }
            } else {
              if (
                this.dataForm.crewSize == 0 ||
                !/(^[1-9]([0-9]+)?(\.[0-9]{1,6})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,6}$)/.test(
                  this.dataForm.crewSize
                )
              ) {
                remindFlag = true
                remindInfo = '【班组人员】需大于0'
              }
            }
            if (remindFlag) {
              this.$message.error(remindInfo)
            } else {
              moRouringOperation(this.dataForm).then((response) => {
                const data = response.data
                if (data.code === 0) {
                  this.currOrderOperation.workCenter = this.dataForm.workCenter
                  this.currOrderOperation.machRunFactor = this.dataForm.machRunFactor
                  this.currOrderOperation.machSetupTime = this.dataForm.machSetupTime
                  this.currOrderOperation.laborClassNo = this.dataForm.laborClassNo
                  this.currOrderOperation.laborRunFactor = this.dataForm.laborRunFactor
                  this.currOrderOperation.laborSetupTime = this.dataForm.laborSetupTime
                  this.currOrderOperation.runTimeCodeDb = this.dataForm.runTimeCodeDb
                  this.currOrderOperation.crewSize = this.dataForm.crewSize
                  this.currOrderOperation.outsideOpItem = this.dataForm.outsideOpItem
                  this.innerVisible = false
                  this.$message.success('编辑成功')
                } else {
                  this.$message.error('编辑失败')
                }
              })
            }
          }
        }
      })
    },
    // 获取IFS人工类别的数据字典
    getLaborClassNo() {
      /* getLaborClassNo().then((response) => {
        if (response.data.code === 0) {
          const _data = response.data.data
          this.laborClassNoOptions = []
          if (_data.length > 0) {
            _data.forEach((item) => {
              const laborClassNoOption = {
                value: item.LC_NO,
                label: item.LC_NO
              }
              this.laborClassNoOptions.push(laborClassNoOption)
            })
          }
        }
      }) */
      remote('labor_class_type').then((response) => {
        if (response.data.code === 0) {
          this.laborClassNoOptions = response.data.data
          this.laborClassNoOptions.forEach((item) => {
            item.label = '[' + item.value + '] ' + item.label
          })
        } else {
          this.laborClassNoOptions = []
        }
      })
    },
    getOutsideOpItem() {
      remote('out_side_type').then((response) => {
        if (response.data.code === 0) {
          this.outsideOpItemOptions = response.data.data
        } else {
          this.outsideOpItemOptions = []
        }
      })
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getLaborClassNo()
          this.getOutsideOpItem()
          remote('runtimecodedb_type').then((response) => {
            if (response.data.code === 0) {
              this.runTimeCodeDbOptions = response.data.data
            }
          })
          remote('work_center_type').then((response) => {
            if (response.data.code === 0) {
              this.workCenterOptions = response.data.data
              this.workCenterOptions.forEach((item) => {
                item.label = '(' + item.value + ') ' + item.label
              })
            }
            this.dataForm.id = this.currOrderOperation.id
            this.dataForm.workCenter = this.currOrderOperation.workCenter
            this.dataForm.machRunFactor = this.currOrderOperation.machRunFactor
            this.dataForm.machSetupTime = this.currOrderOperation.machSetupTime
            this.dataForm.laborClassNo = this.currOrderOperation.laborClassNo
            this.dataForm.laborRunFactor = this.currOrderOperation.laborRunFactor
            this.dataForm.laborSetupTime = this.currOrderOperation.laborSetupTime
            this.dataForm.runTimeCodeDb =
              this.currOrderOperation.runTimeCodeDb == null
                ? '2'
                : this.currOrderOperation.runTimeCodeDb
            this.dataForm.crewSize = this.currOrderOperation.crewSize
            this.dataForm.outsideOpItem = this.currOrderOperation.outsideOpItem
            this.dataForm.moId = this.currOrderOperation.moId
          })
        })
      }
    }
  }
}
</script>
<style>
.edit-order-operation-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.edit-order-operation-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.edit-order-operation-dialog .el-dialog__body {
  padding: 5px 20px;
}

.edit-order-operation-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.edit-order-operation-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
